Struct amazon_sp_vendor_direct_fulfillment_shipping::models::shipping_label::ShippingLabel
source · [−]pub struct ShippingLabel {
pub purchase_order_number: String,
pub selling_party: Box<PartyIdentification>,
pub ship_from_party: Box<PartyIdentification>,
pub label_format: LabelFormat,
pub label_data: Vec<LabelData>,
}Fields
purchase_order_number: StringThis field will contain the Purchase Order Number for this order.
selling_party: Box<PartyIdentification>ship_from_party: Box<PartyIdentification>label_format: LabelFormatFormat of the label.
label_data: Vec<LabelData>Provides the details of the packages in this shipment.
Implementations
sourceimpl ShippingLabel
impl ShippingLabel
pub fn new(
purchase_order_number: String,
selling_party: PartyIdentification,
ship_from_party: PartyIdentification,
label_format: LabelFormat,
label_data: Vec<LabelData>
) -> ShippingLabel